rm(list = ls())

library(tidyr)
library(dplyr)
library(haven)
library(modelsummary)
library(ggplot2)
library(paneltools)
library(fect)
library(fixest)
library(kableExtra)
library(rdrobust)
library(panelView)
library(patchwork)
library(estimatr)
library(doBy)
library(foreign)
library(ggplot2)

df <- read_dta("./data/XuYao2015.dta")
df2 <- read_dta("./data/lineageorg.dta")


##########################
# Figure 1
##########################

# Figure 1(a)
plot(density(df$clansz1,na.rm=T,bw=0.04),ylim=c(0,8),xlab="",ylab="",main="Population of Clans")
mtext("Density", side=2,line=2)
mtext("Population Share", side=1,line=2)
lines(density(df$clansz2,na.rm=T,bw=0.04),lty=5)
lines(density(df$clansz3,na.rm=T,bw=0.04),lty=2)
lines(density(df$clansz4,na.rm=T,bw=0.04),lty=3,lwd=2)
legend("topright", c("Largest", "2nd-largest","3rd-largest", "4th-largest"), 
       lty = c(1,5,2,3), col=1, lwd=c(1,1,1,2), merge = TRUE, cex=1.5,bty="n")  

# ------------------------------------------------------------------------------
# Figure 1(b)
df_clans <- df %>%
  filter(!is.na(year) & !is.na(elecyr)) %>%
  group_by(year) %>%
  summarize(
    largest_clan = sum(vcfirst, na.rm = TRUE),
    second_largest_clan = sum(vcsecond, na.rm = TRUE)
  ) %>%
  ungroup()

## Create a frequency table for total observations by year
freq_table <- table(df$year)
years <- as.numeric(names(freq_table))
freq  <- as.numeric(freq_table)
num_villages_with_elec_vc <- data.frame(year = years, freq = freq)

## Merge clan data with total observations
figure1b <- left_join(df_clans, num_villages_with_elec_vc, by = "year") %>%
  mutate(
    largest_prop = largest_clan / freq,
    second_largest_prop = second_largest_clan / freq
  )

max_freq <- max(figure1b$freq, na.rm = TRUE)
ggplot(figure1b, aes(x = year)) +
  # Left axis: total observations (bars)
  geom_bar(aes(y = freq), stat = "identity", fill = "gray", alpha = 0.5) +
  # Right axis: clan proportions, rescaled to match the bar heights
  geom_line(aes(y = largest_prop * max_freq, color = "Largest Clan"), size = 1) +
  geom_line(aes(y = second_largest_prop * max_freq, color = "Second Largest Clan"), 
            size = 1, linetype = "dashed") +
  scale_y_continuous(
    name = "Number of Villages with Elected VCs",
    limits = c(0, max_freq),
    sec.axis = sec_axis(~ . / max_freq * 100, name = "Percentage %")
  ) +
  scale_color_manual(
    name = "Legend",
    values = c("Largest Clan" = "black", "Second Largest Clan" = "black")
  ) +
  labs(
    x = "Year",
    title = "Number of Elected VCs and Clan Percentages"
  ) +
  theme_minimal()

# ------------------------------------------------------------------------------
# Figure 1(c)
data1c <- read.dta("./data/XuYao2015.dta")
fam1 <- summaryBy(vcfirst + clansz1 ~ vill_id, FUN=c(mean), data=data1c)
fam2 <- summaryBy(vcsecond + clansz2 ~ vill_id, FUN=c(mean), data=data1c)
fam2 <- subset(fam2,clansz2.mean!=0)

plot(1,type="n",xlim=c(0,1),ylim=c(0,100),xlab="",ylab="")
points(unlist(fam2[,3]), fam2[,2]*100, cex=0.7, col="gray80", pch=15)
points(unlist(fam1[,3]),fam1[,2]*100,cex=0.7,col="gray50",pch=16)
lines(loess.smooth(fam1[,3],fam1[,2]*100,degree=1),lwd=2)
lines(loess.smooth(fam2[,3],fam2[,2]*100,degree=1),lwd=2,lty=5)
mtext("Population Share of Large Clans",side=1,line=2)
mtext("Percentage of VCs of Large Clans",side=2,line=2)
legend(0.6,25,pch=c(16,15), col=c("gray50","gray80"), lwd=2, lty=c(1,2),
       c("Largest","2nd-largest"),seg.len=2.8,cex=1.5,bty="n") 

# ------------------------------------------------------------------------------
# Figure 1(d)
data1d <- df %>%
  group_by(year, prov_id, vill_id) %>%
  summarise(
    combined_clan_share = mean(clansz1 + clansz2, na.rm = TRUE),
    vc_large_clan = ifelse(mean(vcfirst == 1 | vcsecond == 1, na.rm = TRUE) > 0.5, 1, 0),
    loginv = mean(loginv, na.rm = TRUE)
  ) %>%
  ungroup()

ggplot(data1d, aes(x = combined_clan_share, y = loginv)) +
  geom_histogram(aes(x = combined_clan_share, y = ..density.. * 0.5), 
                 binwidth = 0.05, fill = "gray", alpha = 0.5) +
  geom_smooth(aes(linetype = as.factor(vc_large_clan)), 
              method = "loess", color = "black", size = 1, se = FALSE) +
  geom_smooth(aes(linetype = "Average"), 
              method = "loess", color = "black", size = 1.5, se = FALSE) +
  labs(
    x = "Population Share of the Two Largest Clans Combined",
    y = "Log Public Investment",
    linetype = NULL
  ) +
  theme_minimal() +
  scale_linetype_manual(
    values = c("dotted", "dashed", "solid"),
    labels = c("VC of large clans = 0", "VC of large clans = 1", "Average")
  ) +
  annotate("text", x = 0.5, y = min(data1d$loginv, na.rm = TRUE) + 0.1, 
           label = "Density of the population share", color = "black", size = 5, hjust = 0) +
  theme(
    legend.position = "top",
    text = element_text(size = 14),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank()
  )


##########################
# Figure 2
##########################
data <- df2 %>%
  filter(!is.na(clan))

# Convert clan to a factor for proper ordering and labeling
data$clan <- factor(data$clan, levels = c(1, 2, 3, 4), 
                    labels = c("Largest clan", "Second-largest clan", 
                               "Third-largest clan", "Fourth-largest clan"))

# Compute proportions (convert to percentages)
summary_data <- data %>%
  group_by(clan) %>%
  summarise(
    `Maintaining a lineage hall` = mean(citang) * 100,
    `Holding annual ceremonies` = mean(cerem) * 100,
    `Lineage hall established before 1978` = mean(citanghis) * 100
  ) %>%
  pivot_longer(cols = -clan, names_to = "Category", values_to = "Percentage")

# Reorder Category levels to match the desired order
summary_data$Category <- factor(
  summary_data$Category,
  levels = c("Maintaining a lineage hall",
             "Holding annual ceremonies",
             "Lineage hall established before 1978")
)

# Create a grouped bar plot in black and white with narrower bars and angled x-axis labels
ggplot(summary_data, aes(x = clan, y = Percentage, fill = Category)) +
  geom_bar(
    stat = "identity",
    position = position_dodge(width = 0.7),
    color = "black",
    width = 0.6
  ) +
  scale_fill_grey(start = 0.2, end = 0.8) +
  labs(x = "", y = "Percentage %") +
  theme_minimal() +
  theme(
    legend.title = element_blank(),
    legend.position = "top",
    axis.text.x = element_text(size = 12, face = "bold", angle = 45, hjust = 1),
    axis.title.y = element_text(size = 14, face = "bold")
  ) +
  coord_cartesian(ylim = c(0, 20))

##########################
# Figure 3
##########################

df <- read_dta("./data/XuYao2015.dta")
data_cohort <- get.cohort(data=df, index =c("vill_id","year"), D = "vcfirst2", start0 = TRUE)
df.twfe <- data_cohort
df.twfe[which(is.na(df.twfe$Time_to_Treatment)),'Time_to_Treatment'] <- 0
twfe.est <- feols(loginv ~ i(Time_to_Treatment, vcfirst2 + hhsize + landpc + logpopl + logincome + logasset +logmigration + logtax + logtransfer, ref = -1)| vill_id +year, data = df.twfe, cluster = "vill_id")
twfe.output <- as.matrix(twfe.est$coeftable)

twfe.output <- as.data.frame(twfe.output)
twfe.output$Time <- c(c(-12:-2),c(0:18))+1 
p.twfe <- esplot(twfe.output,Period = 'Time',Estimate = 'Estimate', SE = 'Std. Error', xlim = c(-12,10))
p.twfe

##########################
# Figure 4
##########################

data2 <- df2 %>%
  group_by(prov_id, vill_id) %>%
  arrange(desc(clansz), .by_group = TRUE) %>%
  mutate(is_top2 = row_number() <= 2) %>%
  mutate(sum_top2 = sum(clansz[is_top2])) %>%
  ungroup() %>%
  mutate(above50 = ifelse(sum_top2 > 0.54, 1, 0))

data4 <- left_join(df, data2, by = c("prov_id", "vill_id"), relationship = "many-to-many")

# Function to run robust regression and extract coefficient + confidence interval
get_coef_CI <- function(data, formula, var_name) {
  fit <- feols(formula, data = data, clusters = ~vill_id)
  est <- coef(fit)[var_name]
  se  <- sqrt(diag(vcov(fit)))[var_name]
  ci  <- est + c(-1, 1) * 1.96 * se
  return(data.frame(est = est, ci_low = ci[1], ci_high = ci[2]))
}


# Perform regressions for each subgroup in three panels

## Panel A: Outcome = above50 (Top-2 clans hold >50% of population)
resA_below <- get_coef_CI(data4 %>% filter(above50 == 1), loginv ~ vcfirst2|year+vill_id, "vcfirst2")
resA_above <- get_coef_CI(data4 %>% filter(above50 == 0), loginv ~ vcfirst2|year+vill_id, "vcfirst2")

## Panel B: Outcome = citang (Presence of lineage hall)
resB_no  <- get_coef_CI(data4 %>% filter(family_tree == 0), loginv ~ vcfirst2|year+vill_id, "vcfirst2")
resB_yes <- get_coef_CI(data4 %>% filter(family_tree == 1), loginv ~ vcfirst2|year+vill_id, "vcfirst2")

## Panel C: Outcome = hall_since_beginning (Historical presence of lineage hall)
resC_no  <- get_coef_CI(data4 %>% filter(citang == 0), loginv ~ vcfirst2|year+vill_id, "vcfirst2")
resC_yes <- get_coef_CI(data4 %>% filter(citang == 1), loginv ~ vcfirst2|year+vill_id, "vcfirst2")

# Combine results into a single dataframe for plotting
plot_data <- rbind(
  data.frame(panel = "A: Relative clan size",
             group = c("Below 50%", "Above 50%"),
             rbind(resA_below, resA_above)),
  data.frame(panel = "B: Records of family trees",
             group = c("No", "Yes"),
             rbind(resB_no, resB_yes)),
  data.frame(panel = "C: Historical Lineage Halls",
             group = c("No", "Yes"),
             rbind(resC_no, resC_yes))
)

p <- ggplot(plot_data, aes(x = group, y = est)) +
  geom_point(size = 3) +  # Larger points for visibility
  geom_errorbar(aes(ymin = ci_low, ymax = ci_high), width = 0.2, size = 0.8) +  # Confidence intervals
  geom_hline(yintercept = 0, linetype = "dashed", color = "gray") +  # Dashed zero-line
  facet_wrap(~panel, scales = "free_x") +  # Separate panels
  labs(x = "", y = "Coefficient of VC of Large Clans") +
  theme_bw() +
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    strip.text = element_text(size = 14, face = "bold"),  # Bold panel headers
    axis.text.x = element_text(size = 12),
    axis.text.y = element_text(size = 12),
    axis.title.y = element_text(size = 14),
    plot.caption = element_text(hjust = 0, size = 11, face = "italic")  # Italicized note
  )

print(p)

##########################
# Figure 5
##########################

df <- df %>% 
  mutate(vcpsfirst2 = vcfirst2 * psfirst2)

# Create interaction variables for each var in {vcps_clan, vcps_person, vc_pb}
for(var in c("vcps_clan", "vcps_person", "vc_pb")){
  df[[paste0(var, "_lgclan")]] <- df$vcfirst2 * df[[var]]
}

# Initialize AA matrix (14 rows x 3 columns)
AA <- matrix(NA, nrow = 14, ncol = 3)

# Helper function to compute linear combinations via the delta method
get_lincom <- function(model, combo) {
  terms <- strsplit(gsub(" ", "", combo), "\\+")[[1]]
  c_vec <- rep(1, length(terms))
  coefs <- coef(model)[terms]
  est <- sum(coefs)
  V <- vcov(model)[terms, terms]
  var_lin <- as.numeric(t(c_vec) %*% V %*% c_vec)
  se <- sqrt(var_lin)
  c(estimate = est, se = se)
}

# --- Block 1 ---
# First regression: without vcps_person variables
m1 <- feols(loginv ~ vcfirst2 + psfirst2 + vcpsfirst2 |vill_id+year, 
            data = df, cluster = ~vill_id)
# Second regression: add vcps_person and its interaction
m2 <- feols(loginv ~ vcfirst2 + psfirst2 + vcps_person + vcpsfirst2 + vcps_person_lgclan|vill_id+year, 
            data = df, cluster = ~vill_id)

# Compute lincoms for Block 1 and store in AA[,1]
lin <- get_lincom(m2, "vcps_person")
AA[1,1] <- lin["estimate"]; AA[2,1] <- lin["se"]

lin <- get_lincom(m2, "psfirst2")
AA[3,1] <- lin["estimate"]; AA[4,1] <- lin["se"]

lin <- get_lincom(m2, "vcfirst2")
AA[5,1] <- lin["estimate"]; AA[6,1] <- lin["se"]

lin <- get_lincom(m2, "vcfirst2+psfirst2+vcpsfirst2")
AA[7,1] <- lin["estimate"]; AA[8,1] <- lin["se"]

lin <- get_lincom(m2, "vcfirst2+psfirst2+vcpsfirst2+vcps_person+vcps_person_lgclan")
AA[9,1]  <- lin["estimate"]; AA[10,1] <- lin["se"]

# --- Block 2 ---
m3 <- feols(loginv ~ vcfirst2 + psfirst2 + vcps_clan + vcpsfirst2 + vcps_clan_lgclan | vill_id+year, 
            data = df, cluster = ~vill_id)

lin <- get_lincom(m3, "vcps_clan")
AA[1,2] <- lin["estimate"]; AA[2,2] <- lin["se"]

lin <- get_lincom(m3, "psfirst2")
AA[3,2] <- lin["estimate"]; AA[4,2] <- lin["se"]

lin <- get_lincom(m3, "vcfirst2")
AA[5,2] <- lin["estimate"]; AA[6,2] <- lin["se"]

lin <- get_lincom(m3, "vcfirst2+psfirst2+vcpsfirst2")
AA[7,2] <- lin["estimate"]; AA[8,2] <- lin["se"]

lin <- get_lincom(m3, "vcfirst2+psfirst2+vcpsfirst2+vcps_clan+vcps_clan_lgclan")
AA[9,2]  <- lin["estimate"]; AA[10,2] <- lin["se"]

# --- Block 3 ---
df <- df %>%
  mutate(vcfirst2_pb = vcfirst2 * vc_pb,
         vc_pb_ps    = vc_pb * psfirst2,
         triple      = vcfirst2 * vc_pb * psfirst2)

m4 <- feols(loginv ~ vcfirst2 + psfirst2 + vc_pb + vcpsfirst2 + vcfirst2_pb + vc_pb_ps + triple| vill_id+year, 
            data = df, cluster = ~vill_id)

lin <- get_lincom(m4, "vc_pb")
AA[1,3] <- lin["estimate"]; AA[2,3] <- lin["se"]

lin <- get_lincom(m4, "vcfirst2")
AA[3,3] <- lin["estimate"]; AA[4,3] <- lin["se"]

lin <- get_lincom(m4, "vcfirst2+vc_pb+vcfirst2_pb")
AA[5,3] <- lin["estimate"]; AA[6,3] <- lin["se"]

lin <- get_lincom(m4, "psfirst2")
AA[7,3] <- lin["estimate"]; AA[8,3] <- lin["se"]

lin <- get_lincom(m4, "vc_pb+psfirst2+vc_pb_ps")
AA[9,3]  <- lin["estimate"]; AA[10,3] <- lin["se"]

lin <- get_lincom(m4, "vcfirst2+psfirst2+vcpsfirst2")
AA[11,3] <- lin["estimate"]; AA[12,3] <- lin["se"]

lin <- get_lincom(m4, "vcfirst2+psfirst2+vc_pb+vcpsfirst2+vcfirst2_pb+vc_pb_ps+triple")
AA[13,3] <- lin["estimate"]; AA[14,3] <- lin["se"]

# --- Plotting ---
x0 <- c(1,7,14)
par(mar = c(5,4,1,1) + 0.1)
plot(1, type = "n", pch = 16, ylim = c(-1,2), xlim = c(0.5,17),
     ylab = "", xlab = "", xaxt = "n", cex.axis = 1, cex.lab = 1, cex = 1.5)
# Points for Block 1, 2, 3 at specific x positions:
points(x0[1] + 0, AA[1,1], pch = 16, cex = 1.5)
points(x0[2] + 0, AA[1,2], pch = 16, cex = 1.5)
points(x0[3] + 0, AA[1,3], pch = 16, cex = 1.5)

points(x0[1] + 1, AA[3,1], pch = 16, cex = 1.5)
points(x0[2] + 1, AA[3,2], pch = 16, cex = 1.5)
points(x0[3] + 1, AA[3,3], pch = 16, cex = 1.5)

points(x0[1] + 2, AA[5,1], pch = 16, cex = 1.5)
points(x0[2] + 2, AA[5,2], pch = 16, cex = 1.5)
points(x0[3] + 2, AA[5,3], pch = 16, cex = 1.5)

points(x0[1:2] + 3, AA[7,1:2], pch = 16, cex = 1.5)
points(x0[1:2] + 4, AA[9,1:2], pch = 16, cex = 1.5)

points(x0[3] - 0.8, AA[7,3], pch = 2, cex = 1.5)
points(x0[3] + 0.2, AA[9,3], pch = 2, cex = 1.5)
points(x0[3] + 1.2, AA[11,3], pch = 2, cex = 1.5)
points(x0[3] + 2.2, AA[13,3], pch = 2, cex = 1.5)

# Add error bars for each lincom result:
for (i in 1:5) {
  segments(i + x0[1] - 1,
           AA[i*2 - 1, 1] - 1.96 * AA[i*2, 1],
           i + x0[1] - 1,
           AA[i*2 - 1, 1] + 1.96 * AA[i*2, 1])
}
for (i in 1:5) {
  segments(i + x0[2] - 1,
           AA[i*2 - 1, 2] - 1.96 * AA[i*2, 2],
           i + x0[2] - 1,
           AA[i*2 - 1, 2] + 1.96 * AA[i*2, 2])
}
for (i in 1:3) {
  segments(i + x0[3] - 1,
           AA[i*2 - 1, 3] - 1.96 * AA[i*2, 3],
           i + x0[3] - 1,
           AA[i*2 - 1, 3] + 1.96 * AA[i*2, 3])
}
for (i in 1:4) {
  segments(i + x0[3] - 1.8,
           AA[i*2 + 5, 3] - 1.96 * AA[i*2 + 6, 3],
           i + x0[3] - 1.8,
           AA[i*2 + 5, 3] + 1.96 * AA[i*2 + 6, 3],
           lty = 2)
}
for (i in c(6,12)) {
  segments(i, -10, i, 10)
}
abline(h = 0, col = "gray", lty = 2, lwd = 2)

tkpos <- c(1:5, 7:11, 14:16)
text(3, 1.95, 'A: "One shoulder"', cex = 1.5)
text(9, 1.95, "B: Same clan", cex = 1.5)
text(14.6, 1.95, "C: VC in the party branch", cex = 1.5)
mtext("Effect of interest", 2, line = 2.5, cex = 1.5)
axis(1, at = c(tkpos, 13.2), labels = FALSE, tick = TRUE)
axis(1, at = tkpos, labels = c("A1","A2","A3","A4","A5",
                               "B1","B2","B3","B4","B5",
                               "C1","C2","C3"), tick = FALSE)
axis(1, at = (13:16) + 0.2, labels = c("C4","C5","C6","C7"), cex.axis = 1, tick = FALSE, line = 1)


# ---- Table ------# 
# Model 1: PS & VC

model_party1 <- feols(loginv ~ vcfirst2 * psfirst2
                      | vill_id + year, data = df, cluster = ~vill_id)

# Model 2: One-Shoulder
model_party2 <- feols(loginv ~ vcfirst2 * psfirst2 * vcps_person 
                      | vill_id + year, data = df, cluster = ~vill_id)

# Model 3: Same Clan
model_party3 <- feols(
  loginv ~ vcfirst2 * psfirst2 * vcps_clan 
  | vill_id + year, data = df, cluster = ~vill_id)

# Model 4: In Party Branch
model_party4 <- feols(loginv ~ vcfirst2 * psfirst2 * vc_pb | 
                        vill_id + year, data = df, cluster = ~vill_id)

# Present results
models_party <- list(
  "Party Secretary" = model_party1, 
  "One-Shoulder" = model_party2,
  "Same Clan" = model_party3, 
  "In Party Branch" = model_party4
)

modelsummary(models_party,
             stars = TRUE,
             title = "Regression Results: Party Secretary and Clan Relationships",
             gof_map = c("nobs", "r.squared", "adj.r.squared"),
             coef_rename = c(
               "vcfirst2:psfirst2" = "Village Chairperson * Party Secretary (Large Clan)",
               "vcfirst2" = "Large Clan Village Chairperson",
               "psfirst2" = "Large Clan Party Secretary",
               "vcps_person" = "One Shoulder",
               "vcps_clan" = "Same Clan",
               "vc_pb" = "Party Branch",
               "vcfirst2:vc_pb" = "Village Chairperson * Party Branch", 
               "psfirst2:vc_pb" = "Party Secretary * Party Branch", 
               "vcfirst2:vcps_person" =  "Village Chairperson * One Shoulder",
               "vcfirst2:vcps_clan" = "Village Chairperson * Same Clan", 
               "vcfirst2:psfirst2:vcps_person" = "Village Chairperson * Party Secretary * One Shoulder",
               "vcfirst2:psfirst2:vcps_clan" = "Village Chairperson * Party Secretary * Same Clan",
               "vcfirst2:psfirst2:vc_pb" = "Village Chairperson * Party Secretary * In Party Branch"
             ))


##########################
# Figure 6
##########################

df6 <- df %>%
  filter(!vote %in% c(0, 1)) %>%
  mutate(
    vote_bin = cut(vote, breaks = seq(0, 1, 0.05), include.lowest = TRUE, right = FALSE),
    vote_bin_mid = (as.numeric(vote_bin) - 1) * 0.05 + 0.025
  )


mod_loginv <- feols(loginv ~ factor(prov_id)*year | vill_id + year, data = df6)
df6 <- df6 %>% mutate(loginv_ad = resid(mod_loginv))

df_avg <- df6 %>%
  group_by(vote_bin_mid) %>%
  summarise(avg_loginv_ad = mean(loginv_ad, na.rm = TRUE))

# Plot: binned averages with lowess curves by vcfirst2 group, with a dashed dark grey line at x = 0.5
ggplot() +
  geom_point(data = df_avg, aes(x = vote_bin_mid, y = avg_loginv_ad)) +
  geom_smooth(data = filter(df6, vcfirst2 == 0), aes(x = vote, y = loginv_ad), 
              method = "loess", se = TRUE, color = "navy") +
  geom_smooth(data = filter(df6, vcfirst2 == 1), aes(x = vote, y = loginv_ad), 
              method = "loess", se = TRUE, color = "red") +
  geom_vline(xintercept = 0.5, linetype = "dashed", color = "darkgrey") +
  scale_y_continuous(breaks = seq(-1.5, 1.5, 0.5)) +
  labs(title = "Robustness Check: A Regression Discontinuity Design",
       x = "Vote",
       y = "Residualized Public Goods Investment") +
  theme_minimal()

##########################
# Figure 7(a)
##########################

# ----------------------------------
# 1) Run the updated model with FE
# ----------------------------------
mod_levies <- feols(
  log_levies ~ inv + vcfirst2 + inv:vcfirst2 | vill_id + year,
  cluster = "vill_id",
  data = df
)

# ----------------------------------
# 2) Extract coefficients & vcov
# ----------------------------------
b  <- coef(mod_levies)
vc <- vcov(mod_levies)

# ----------------------------------
# 3) Helper to get linear combos
# ----------------------------------
lincombo <- function(coefs, covmat, combo) {
  est <- sum(coefs[names(combo)] * combo)
  se  <- sqrt(as.numeric(t(combo) %*% covmat[names(combo), names(combo)] %*% combo))
  c(est = est, se = se, lower = est - 1.96 * se, upper = est + 1.96 * se)
}

# ----------------------------------
# 4) Compute estimates for:
#    - small clan & no project (baseline = 0)
#    - small clan & project
#    - large clan & no project
#    - large clan & project
# ----------------------------------
est1 <- c(est=0, se=0, lower=0, upper=0)  # baseline
est2 <- lincombo(b, vc, c(inv=1))
est3 <- lincombo(b, vc, c(vcfirst2=1))
est4 <- lincombo(b, vc, c(inv=1, vcfirst2=1, `inv:vcfirst2`=1))

fg_ca <- data.frame(
  rbind(est1, est2, est3, est4),
  row.names = c("SmallClan_NoProject","SmallClan_Project","LargeClan_NoProject","LargeClan_Project")
)

# ----------------------------------
# 5) Plot the four estimates
# ----------------------------------
plot(
  x = c(1,2,4,5),
  y = fg_ca$est,
  pch = 19,
  axes = FALSE,
  xlab = "",
  ylab = "",
  xlim = c(0,6),
  ylim = range(fg_ca[, c("lower","upper")], na.rm=TRUE)
)

# Optional shading for style
polygon(c(-1,3,3,-1), c(-999, -999, 999, 999), col="grey90", border=NA)

abline(h = fg_ca$est[1], col="gray")  # baseline = 0
points(c(1,2,4,5), fg_ca$est, pch=19)

arrows(
  c(1,2,4,5), fg_ca$lower,
  c(1,2,4,5), fg_ca$upper,
  code=3, angle=90, length=0.05
)

segments(1, fg_ca$est[1], 2, fg_ca$est[2], col="gray20", lty=2)
segments(4, fg_ca$est[3], 5, fg_ca$est[4], col="gray20", lty=2)

box()
axis(side=2)
axis(side=1, tick=FALSE, line=-1,
     at = c(1,2.1,4,5.1),
     labels = c("No project","Project","No project","Project"))
axis(side=1, tick=FALSE, line=1,
     at = c(1.5,4.5),
     labels = c("VCs of small clans","VCs of large clans"))


##########################
# Figure 7(b)
##########################

# ----------------------------------
# 1) For each percentile p in (10,20,...,90),
#    run a regression of log_levies_pXX on inv + FE
# ----------------------------------
income_levels <- seq(10, 90, by=10)
out_mat <- matrix(NA, nrow=length(income_levels), ncol=4,
                  dimnames=list(NULL, c("est","se","lower","upper")))

for(i in seq_along(income_levels)) {
  p <- income_levels[i]
  # Construct the outcome name, e.g. "log_levies_p10"
  yvar <- paste0("log_levies_p", p)
  
  # Fit the model: controlling for village and year FE, cluster by vill_id
  form <- as.formula(paste0(yvar, " ~ inv | vill_id + year"))
  mod_p <- feols(form, cluster = "vill_id", data = df)
  
  # Extract coefficient on inv
  b  <- coef(mod_p)["inv"]
  vc <- vcov(mod_p)["inv","inv"]
  se <- sqrt(vc)
  
  out_mat[i,] <- c(
    est   = b,
    se    = se,
    lower = b - 1.96 * se,
    upper = b + 1.96 * se
  )
}

# ----------------------------------
# 2) Plot: x-axis = income percentile, y-axis = coefficient on inv
# ----------------------------------
X <- income_levels
plot(
  X, out_mat[,"est"],
  type = "l",
  ylim = c(-0.2, 1),  # adjust to your data range
  xlim = c(0, 100),
  xlab = "",
  ylab = ""
)

# Add axis labels and title
mtext(side = 1, line = 2, "Income Percentile")
mtext(side = 2, line = 2, "Village Public Investment on Log Levies")
mtext(side = 1, line = 4, "(b) Levies and public investment by villagers’ income")

# Add confidence intervals
arrows(
  X, out_mat[,"lower"],
  X, out_mat[,"upper"],
  code = 3, angle = 90, length = 0.05
)
# Add points on top of the line
points(X, out_mat[,"est"], pch=19)
# Reference line at 0
abline(h=0, col="gray", lty=2, lwd=2)

