rm(list = ls())

library(tidyr)
library(dplyr)
library(haven)
library(modelsummary)
library(ggplot2)
library(fect)
library(fixest)

df <- read_dta("./data/XuYao2015.dta")
df2 <- read_dta("./data/lineageorg.dta")


##############################
## Table 1
##############################

# Village-Year Observations
vars1 <- c("inv", "loginv", "log_levies", "logpopl", "logincome", "logasset", 
           "hhsize","landpc", "logmigration", "logtax", "logtransfer", "share_admin", 
           "postcont", "postopen", "secret_ballot", "proxy_voting", "moving_ballot")

datasummary_skim(df %>% select(all_of(vars1)))

# Village Chairperson (by Term)
df_elecyr <- df %>% filter(elecyr == 1)
vars2 <- c("vcfirst", "vcsecond", "vcfirst2", grep("^vc_char_", names(df), value = TRUE),
           "vote", "psfirst2", "vcps_clan", "vcps_person", "vc_pb")

datasummary_skim(df_elecyr %>% select(all_of(vars2)))

# Sample village (as of 2005)
df_2005 <- df %>% filter(year == 2005)
vars3 <- c("clan_num", grep("^clansz", names(df), value = TRUE), "largeclan", "family_tree", "ances_hall")

datasummary_skim(df_2005 %>% select(all_of(vars3)))


##############################
## Table 2
##############################
# Model 1
model1 <- feols(loginv ~ vcfirst + vcsecond | year, data = df, cluster = ~vill_id)

# Model 2
model2 <- feols(loginv ~ vcfirst + vcsecond | vill_id + year, data = df, cluster = ~vill_id)

# Model 3
model3 <- feols(loginv ~ vcfirst + vcsecond + factor(prov_id):year | vill_id + year , 
                data = df, cluster = ~vill_id)

# Model 4
model4 <- feols(loginv ~ vcfirst + vcsecond + factor(vill_id):year| vill_id + year, 
                data = df, cluster = ~vill_id)

# Model 5
model5 <- feols(loginv ~ vcfirst + vcsecond + hhsize + landpc + logpopl + logincome + 
                  logasset + factor(prov_id):year| + vill_id + year, data = df, cluster = ~vill_id)

# Model 6
model6 <- feols(loginv ~ vcfirst + vcsecond + hhsize + landpc + logpopl + logincome + 
                  logasset + logmigration + logtax + logtransfer + 
                  factor(prov_id):year| vill_id + year, data = df, cluster = ~vill_id)

models_table2 <- list("Model 1" = model1, "Model 2" = model2, "Model 3" = model3,
                      "Model 4" = model4, "Model 5" = model5, "Model 6" = model6)

models_table2 <- list(
  "(1)" = model1,
  "(2)" = model2,
  "(3)" = model3,
  "(4)" = model4,
  "(5)" = model5,
  "(6)" = model6
)

modelsummary(
  models_table2,
  fmt = 3,
  stars = TRUE,
  coef_map = c(
    "vcfirst"  = "VC of the largest clan",
    "vcsecond" = "VC of the second-largest clan"
  ),
  # Omit all other terms you do not want in the main coefficient block:
  coef_omit = "Intercept|vill_id|year|prov_id|hhsize|landpc|logpopl|logincome|logasset|logmigration|logtax|logtransfer",
  # Omit unneeded goodness-of-fit stats:
  gof_omit = "AIC|BIC|RMSE|Within|R2",
  add_rows = tribble(
    ~term,                 ~`(1)`, ~`(2)`, ~`(3)`, ~`(4)`, ~`(5)`, ~`(6)`,
    "Prov. linear trends", "",     "",     "x",    "",     "x",    "x",
    "NFS controls",        "",     "",     "",     "",     "x",    "x",
    "Migrants out",        "",     "",     "",     "",     "",     "x",
    "Taxes (upper-level)", "",     "",     "",     "",     "",     "x",
    "Transfers (upper)",   "",     "",     "",     "",     "",     "x",
  ),
  output = "html"
)

##############################
## Table 3
##############################

vars <- grep("^loginv_cat_", names(df), value = TRUE)

models_feols <- lapply(vars, function(v) {
  feols(
    as.formula(paste0(v, " ~ vcfirst2 | vill_id + year")), 
    data    = df,
    cluster = "vill_id"
  )
})
names(models_feols) <- c("Schooling", "Road & Sanitation", "Electricity", "Irrigation", "Forestation", "Others") 

modelsummary(
  setNames(models_feols, c("Schooling", "Road & Sanitation", "Electricity", "Irrigation", "Forestation", "Others")),
  fmt = 3,
  stars = TRUE,
  coef_rename = c(
    "vcfirst2" = "VC of the largest clan"
  ),
  gof_omit = "AIC|BIC|RMSE|Within|R2",
  title  = "VCs of Large Clans and Village Public Investment: by Project Type",
  output = "default"
)


##############################
## Table 4
##############################

mod1 <- feols(log_levies ~ vcfirst2| vill_id + year, data = df, cluster = ~vill_id)
mod2 <- feols(log_levies ~ inv| vill_id + year, data = df, cluster = ~vill_id)
mod3 <- feols(log_levies ~ vcfirst2 + inv + vcfirst2:inv| vill_id+year, 
              data = df, cluster = ~vill_id)

models_table4 <- list("Model 1" = mod1, "Model 2" = mod2,"Model 3" = mod3)

modelsummary(
  models_table4,
  fmt = 3,                         # decimal places
  stars = TRUE,                    # significance stars
  coef_rename = c(
    "vcfirst2"     = "VCof large clans",
    "inv"       = "Public Goods Investment",
    "vcfirst2:inv" = "VCof large clans x Public Goods Investment"
  ),
  title   = "VCs of Large Clans and Levies",
  gof_omit = "AIC|BIC|RMSE|Within|R2",
  notes   = "Note: All regressions include village and year fixed effects, with SEs clustered by village."
)

##############################
## Table 5
##############################

mod1 <- feols(share_admin ~ vcfirst2| vill_id + year, data = df, cluster = ~vill_id)
mod2 <- feols(log_admin ~ vcfirst2| vill_id + year, data = df, cluster = ~vill_id)

models_table5 <- list("Share of administrative expenditure in total expenditure" = mod1, "Log administrative expenditure (1,000 yuan)" = mod2)

modelsummary(
  models_table5,
  fmt = 3,             # decimal places
  stars = TRUE,        # significance stars
  coef_rename = c("vcfirst2" = "VC of the largest clan"),
  title = "VCs of Large Clans and Administrative Expenditure",
  gof_omit = "AIC|BIC|RMSE|Within|R2",
  notes = "Note: All regressions include village and year fixed effects, with SEs clustered by village."
)

##############################
## Table 6
##############################

mod1 <- feols(loginv ~  vcfirst2 + vc_char_educ| vill_id + year, 
              cluster = ~ vill_id, data = df)

mod2 <- feols(loginv ~ vcfirst2 + vc_char_educ + vc_char_age + vc_char_ccp + 
                vc_char_cadre + vc_char_manager + vc_char_exper | vill_id + year,
              cluster = ~ vill_id, data = df )

mod3 <- feols(loginv ~ vcfirst2 + vc_char_educ + vc_char_age + vc_char_ccp + 
                vc_char_cadre + vc_char_manager + vc_char_exper + vc_char_bkpoor + vc_char_pidou
              | vill_id + year, cluster = ~ vill_id, data = df)

# Custom labels for coefficients
cm <- c(
  "largeclan"       = "VC of large clans",
  "VC_char_edu"     = "Years of education",
  "VC_char_age"     = "Age when running",
  "VC_char_ccp"     = "CCP member",
  "VC_char_cadre"   = "Village cadre when running",
  "VC_char_manager" = "Managerial jobs when running",
  "VC_char_exper"   = "Elections run before",
  "VC_char_bg"      = "Family background: poor peasant",
  "VC_char_piduo"   = "Denounced in the Cultural Revolution"
)


cm <- c(
  "vcfirst2"        = "VC of large clans",
  "vc_char_educ"    = "Years of education",
  "vc_char_age"     = "Age when running election/10",
  "vc_char_ccp"     = "CCP member",
  "vc_char_cadre"   = "Village cadre when running election",
  "vc_char_manager" = "Managerial job when running election",
  "vc_char_exper"   = "Experience of running election",
  "vc_char_bkpoor"  = "Family background: poor peasant",
  "vc_char_pidou"   = "Denounced in the Culture Revolution (pidou)"
)

# Display the results side by side
modelsummary(
  list("(1)" = mod1, "(2)" = mod2, "(3)" = mod3),
  coef_map = cm,
  stars = TRUE,
  title = "Large Clans, VCs' Characteristics, and Village Public Investment",
  gof_omit = "AIC|BIC|RMSE|Within|R2")

##############################
## Table 7
##############################

mod1 <- feols(loginv ~ vcfirst2 + postcont
              | vill_id + year, cluster = ~ vill_id, data = df)

mod2 <- feols(loginv ~ vcfirst2 + postopen
              | vill_id + year, cluster = ~ vill_id, data = df)

mod3 <- feols(loginv ~ vcfirst2 + secret_ballot 
              | vill_id + year, cluster = ~ vill_id, data = df)

mod4 <- feols(loginv ~ vcfirst2 + proxy_voting 
              | vill_id + year, cluster = ~ vill_id, data = df)

mod5 <- feols(loginv ~ vcfirst2 + moving_ballot 
              | vill_id + year, cluster = ~ vill_id, data = df)

mod6 <- feols(loginv ~ vcfirst2 | vill_id + year, 
              cluster = ~ vill_id, data = subset(df, postcont=1))

mod7 <- feols(loginv ~ vcfirst2 | vill_id + year, 
              cluster = ~ vill_id, data = subset(df, postopen=1))

mod_all <- feols(
  loginv ~ vcfirst2 + postcont + postopen + secret_ballot + proxy_voting + moving_ballot 
  + logpopl + logincome| vill_id + year, cluster = ~ vill_id, data = df)


cm <- c(
  "vcfirst2"      = "VC of large clans",
  "postcont"      = "Contested election",
  "postopen"       = "Open nomination",
  "secret_ballot"  = "Secret ballot",
  "proxy_voting"   = "Proxy voting",
  "moving_ballot"  = "Moving ballot",
  "logpopl"        = "Log(village population)",
  "logincome"        = "Log(income per capita)"
)



# Display the five models side by side
modelsummary(
  list("(1) " = mod1,
       "(2) " = mod2,
       "(3) " = mod3,
       "(4)" = mod4,
       "(5)" = mod5,
       "(6), Contested" = mod6,
       "(7), Open Nom." = mod7,
       "(8), Full control" = mod_all),
  coef_map = cm,
  stars = TRUE,
  gof_omit = "AIC|BIC|RMSE|Within|R2",
  title = "VCs of Large Clans, Electoral Institutions, and Village Public Investment"
)

